@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2017-2019 Red Hat Inc
- * SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+ * SPDX-FileCopyrightText: 2020-2022 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  *
@@ -160,8 +160,8 @@ bool AppFilterModel::filterAcceptsRow(int source_row, const QModelIndex &source_
         return m_showOnlyPreferredApps ? category == ApplicationItem::PreferredApplication : true;
     }
 
-    return m_showOnlyPreferredApps ? category == ApplicationItem::PreferredApplication && appName.toLower().contains(m_filter)
-                                   : appName.toLower().contains(m_filter);
+    return m_showOnlyPreferredApps ? category == ApplicationItem::PreferredApplication && appName.contains(m_filter, Qt::CaseInsensitive)
+                                   : appName.contains(m_filter, Qt::CaseInsensitive);
 }
 
 bool AppFilterModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
@@ -219,8 +219,22 @@ AppModel::~AppModel()
 {
 }
 
-void AppModel::setPreferredApps(const QStringList &list)
+void AppModel::setPreferredApps(const QStringList &possiblyAliasedList)
 {
+    m_hasPreferredApps = false;
+    Q_EMIT hasPreferredAppsChanged();
+
+    // In the event that we get incoming NoDisplay entries that are AliasFor another desktop file,
+    // switch the NoDisplay name for the aliased name.
+    QStringList list;
+    for (const auto &entry : possiblyAliasedList) {
+        if (const auto value = m_noDisplayAliasesFor.value(entry); !value.isEmpty()) {
+            list << value;
+        } else {
+            list << entry;
+        }
+    }
+
     for (ApplicationItem &item : m_list) {
         bool changed = false;
 
@@ -233,6 +247,8 @@ void AppModel::setPreferredApps(const QStringList &list)
         if (list.contains(item.applicationDesktopFile())) {
             item.setApplicationCategory(ApplicationItem::PreferredApplication);
             changed = true;
+            m_hasPreferredApps = true;
+            Q_EMIT hasPreferredAppsChanged();
         }
 
         if (changed) {
@@ -287,12 +303,20 @@ QHash<int, QByteArray> AppModel::roleNames() const
 void AppModel::loadApplications()
 {
     const KService::List appServices = KApplicationTrader::query([](const KService::Ptr &service) -> bool {
-        return service->isValid() && !service->noDisplay() /* includes platform and desktop considerations */;
+        return service->isValid();
     });
     for (const KService::Ptr &service : appServices) {
+        if (service->noDisplay()) {
+            if (const auto alias = service->aliasFor(); !alias.isEmpty()) {
+                m_noDisplayAliasesFor.insert(service->desktopEntryName(), service->aliasFor());
+            }
+            continue; // no display after all
+        }
+
         const QString fullName = service->property(QStringLiteral("X-GNOME-FullName"), QVariant::String).toString();
         const QString name = fullName.isEmpty() ? service->name() : fullName;
         ApplicationItem appItem(name, service->icon(), service->desktopEntryName());
+
         if (!m_list.contains(appItem)) {
             m_list.append(appItem);
         }
