@@ -8,6 +8,7 @@
  */
 
 #include "filechooser.h"
+#include "filechooser_debug.h"
 #include "utils.h"
 
 #include <QDBusArgument>
@@ -18,7 +19,6 @@
 #include <QFileInfo>
 #include <QGridLayout>
 #include <QLabel>
-#include <QLoggingCategory>
 #include <QPushButton>
 #include <QQmlApplicationEngine>
 #include <QStandardPaths>
@@ -37,8 +37,6 @@
 #include "request.h"
 #include <mobilefiledialog.h>
 
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeFileChooser, "xdp-kde-file-chooser")
-
 // Keep in sync with qflatpakfiledialog from flatpak-platform-plugin
 Q_DECLARE_METATYPE(FileChooserPortal::Filter)
 Q_DECLARE_METATYPE(FileChooserPortal::Filters)
@@ -234,7 +232,7 @@ static QStringList fuseRedirect(QList<QUrl> urls)
 
     qCDebug(XdgDesktopPortalKdeFileChooser) << "mounted urls with fuse, maybe" << urls;
 
-    return QUrl::toStringList(urls);
+    return QUrl::toStringList(urls, QUrl::FullyEncoded);
 }
 
 uint FileChooserPortal::OpenFile(const QDBusObjectPath &handle,
@@ -590,8 +588,15 @@ uint FileChooserPortal::SaveFile(const QDBusObjectPath &handle,
     }
 
     if (!currentName.isEmpty()) {
-        const QUrl url = fileDialog->m_fileWidget->baseUrl();
-        fileDialog->m_fileWidget->setSelectedUrl(QUrl::fromLocalFile(QStringLiteral("%1/%2").arg(url.toDisplayString(QUrl::StripTrailingSlash), currentName)));
+        QUrl url = fileDialog->m_fileWidget->baseUrl();
+        QString path = url.path();
+        if (path.back() == QLatin1Char('/')) {
+            path = path + currentName;
+        } else {
+            path = path + QLatin1Char('/') + currentName;
+        }
+        url.setPath(path);
+        fileDialog->m_fileWidget->setSelectedUrl(url);
     }
 
     if (!acceptLabel.isEmpty()) {
